import 'base_document.dart';

/// Class representing a CosmosDB permission.
class Permission extends BaseDocumentWithEtag {
  Permission(this.id, this.mode, this.resource, this.token);

  @override
  final String id;

  /// The permission's mode (`Read` or `All`).
  final String mode;

  /// The resource covered by this permission.
  final String resource;

  /// The permission's token generated by CosmosDB.
  final String? token;

  @override
  Map<String, dynamic> toJson() =>
      {'id': id, 'permissionMode': mode, 'resource': resource};

  /// Builds a [Permission] from a CosmosDB JSON object.
  static Permission build(Map json) {
    final permission = Permission(
        json['id'], json['permissionMode'], json['resource'], json['_token']);
    permission.setEtag(json);
    return permission;
  }
}
